@@ -4,6 +4,7 @@ import datetime
 import json
 import os
 import pathlib
+import time
 from functools import partial
 from multiprocessing.pool import Pool
 from time import sleep
@@ -66,6 +67,73 @@ def get_retailer_version_task(retailer_dict):
     return d
 
 
+@api.command()
+@click.argument('title', type=click.STRING)
+@click.argument('group', type=click.STRING)
+@click.argument('description', type=click.STRING)
+@click.argument('yaml_template', type=click.File())
+@pass_rebotics_context
+def save_test_case(ctx, title, group, description, yaml_template):
+    """
+    Save test case in core.
+    ARGS:
+        title - STR,
+        group - STR,
+        description - STR,
+        yaml_template - File
+    """
+    click.echo('Save core test case')
+    yaml_template = yaml_template.read()
+
+    try:
+        ctx.provider.create_core_test_case(title=title,
+                                           group=group,
+                                           description=description,
+                                           yaml_template=yaml_template)
+        click.echo('Done')
+    except Exception as exc:
+        raise click.ClickException(str(exc))
+
+
+@api.command()
+@click.argument('title', type=click.STRING)
+@click.argument('group', type=click.STRING)
+@click.argument('description', type=click.STRING)
+@click.argument('yaml_template', type=click.File())
+@click.option('--target', type=click.Path(exists=False, file_okay=True, dir_okay=True), default=None)
+@pass_rebotics_context
+def retrieve_test_case_data(ctx, title, group, description, yaml_template, target):
+    """
+    Retrieve data for test case from core.
+    ARGS:
+        title - STR,
+        group - STR,
+        description - STR,
+        yaml_template - File,
+        target - Path
+    """
+    click.echo('Rendering test_case data')
+    yaml_template = yaml_template.read()
+
+    try:
+        res = ctx.provider.retrieve_core_test_case_data(title=title,
+                                                        group=group,
+                                                        description=description,
+                                                        yaml_template=yaml_template)
+
+        if target is None:
+            ctx.format_result(res)
+        else:
+            target = pathlib.Path(target)
+            if target.is_dir():
+                target = target / f"test_case_{time.strftime('%d-%m-%Y_%H:%M')}.json"
+            with open(target, 'w') as fd:
+                fd.write(json.dumps(res, indent=2))
+                click.echo(f'Download to {target}')
+    except Exception as exc:
+        raise click.ClickException(str(exc))
+
+
 @api.command()
 @click.argument('retailer')
 @pass_rebotics_context
@@ -77,7 +145,7 @@ def configurations(ctx, retailer):
         res = ctx.provider.get_configurations(retailer)
         ctx.format_result(res)
     except Exception as exc:
-        raise click.ClickException(exc)
+        raise click.ClickException(str(exc))
 
 
 @api.command()
@@ -163,7 +231,7 @@ def models(ctx, retailer):
             ctx.provider.get_retailer_tf_models(codename=retailer)
         )
     except Exception as exc:
-        raise click.ClickException(exc)
+        raise click.ClickException(str(exc))
 
 
 @api.command()
@@ -382,7 +450,7 @@ def rcdb_previews_fs(ctx, argument, output, concurrency):
     try:
         with open(filepath, 'rb') as fp:
             definition = json.load(fp)
-    except:
+    except Exception:
         raise click.ClickException(f"File is not supported. Please check it at {filepath}")
 
     # apply a script
@@ -391,7 +459,7 @@ def rcdb_previews_fs(ctx, argument, output, concurrency):
         df = pd.DataFrame(definition)
         df.to_csv(output / "definition.csv", quoting=csv.QUOTE_NONNUMERIC)
         del df
-    except:
+    except Exception:
         pass
 
     with Pool(concurrency) as pool:
@@ -446,7 +514,7 @@ def stitching_setup(ctx, argument, concurrency, output):
         try:
             with open(filepath, 'rb') as fp:
                 definition = json.load(fp)
-        except:
+        except Exception:
             raise click.ClickException(f"File is not supported. Please check it at {filepath}")
 
     if 'data' in definition:
@@ -478,7 +546,7 @@ def stitching_setup(ctx, argument, concurrency, output):
             files_to_load.append([
                 call_data['image_url'], call_folder / "server_stitched_image.jpeg"
             ])
-        except:
+        except Exception:
             ctx.verbose_log("No stitching image is available")
 
         if input_data.get('mask_od_url'):
