@@ -156,6 +156,15 @@ class AdminProvider(ReboticsBaseProvider):
             'yaml_template': yaml_template,
         })
 
+    @remote_service('/core-test/core-test-case/payload/')
+    def retrieve_core_test_case_data(self, yaml_template, title, group, description):
+        return self.session.post(json={
+            'title': title,
+            'group': group,
+            'description': description,
+            'yaml_template': yaml_template,
+        })
+
     @remote_service('/core-test/cases/{id}/')
     def get_core_test_case(self, id_):
         return self.session.get(id=id_)
