@@ -10,7 +10,7 @@ class DatasetProvider(ReboticsBaseProvider):
     def api_root(self):
         return self.session.get()
 
-    @remote_service('/api/v1/token-auth/')
+    @remote_service('/api/v1/token-auth/', raw=True)
     def token_auth(self, username, password, verification_code=None):
         payload = dict(
             username=username,
@@ -19,9 +19,9 @@ class DatasetProvider(ReboticsBaseProvider):
         if verification_code is not None:
             payload['verification_code'] = verification_code
 
-        json_data = self.session.post(data=payload)
-        self.headers['Authorization'] = 'Token %s' % json_data['token']
-        return json_data
+        response = self.session.post(data=payload)
+        self.headers['Authorization'] = 'Token %s' % response.json()['token']
+        return response
 
     @remote_service('/api/v1/import_training_data/', timeout=10000)
     def import_training_data(self, data):
