@@ -116,7 +116,7 @@ def uri_validator(x):
     try:
         result = urlparse(x)
         return all([result.scheme, result.netloc, result.path])
-    except:
+    except Exception:
         return False
 
 
@@ -136,7 +136,7 @@ def download_and_return_id(row, output: pathlib.Path):
         try:
             remote_loaders.download(url, destination)
             return uuid, destination
-        except:
+        except Exception:
             retries -= 1
 
     return uuid, None
