@@ -1,5 +1,6 @@
 import pathlib
 import tempfile
+import requests_mock
 
 import pytest
 
@@ -81,7 +82,8 @@ def test_zip_packing():
 def test_virtual_packing_and_unpacking(script_cwd):
     db_folder = pathlib.Path(script_cwd.join("db"))
 
-    with tempfile.TemporaryDirectory() as dirname:
+    with tempfile.TemporaryDirectory() as dirname, requests_mock.Mocker() as m:
+        m.get('https://via.placeholder.com/150', text='some file')
         destination_filename = pathlib.Path(dirname, 'test')
         # destination_filename = db_folder / "test.rcdb"
         packer = VirtualClassificationDatabasePacker(destination=destination_filename)
