@@ -44,10 +44,3 @@ def test_processing_action_group_invoke():
 def test_configure_command():
     runner = CliRunner()
     # result = runner.invoke(api, ['-r', 'local', 'configure'])
-
-
-def test_camera_settings_add_roi():
-    runner = CliRunner()
-    from rebotics_sdk.cli.shelf_camera_manager import api
-
-    result = runner.invoke(api, ['camera-settings', 'add-roi'])
